containertools.get_first_container_in_proper_parentage_of_component
===================================================================

.. autofunction:: abjad.tools.containertools.get_first_container_in_proper_parentage_of_component.get_first_container_in_proper_parentage_of_component
